|Astropy| |PyPI| |Travis_Build| |Issues| |RTD| |License| |Coverage|

.. _main_docs:

******************************
SDSS_Catl_Utils Documentation
******************************

``SDSS_Catl_Utils`` is a specialized python package for downloading and
analyzing catalogues of galaxies and dark matter haloes. The core
functionality of the package includes:

* Easy interface to download desired galaxy catalogues from **Calderon et al. (2019)**
* A modular, object-oriented framework for handling the galaxy catalogues.
* End-to-end support for reducing galaxy catalogues and caching them as fast-loading hdf5 files.

The source code is freely available at
`https://github.com/vcalderon2009/sdss_catl_utils <https://github.com/vcalderon2009/sdss_catl_utils>`_ 

.. _main_getting_started:

===============
Getting Started
===============

.. toctree::
    :maxdepth: 1

    install
    importing_sdss_catl_utils
    quickstart_and_tutorials/index


===============
What's New?
===============

.. toctree::
    :maxdepth: 1

    whatsnew/0.0.1
    whatsnew/index
    changelog

===============
Project Details
===============

.. toctree::
    :maxdepth: 1

    credits
    license
    ./full_ref_api/sdss_catl_utils_full_api.rst
    sdss_catl_utils/index

===============
Reference
===============

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. Links

.. |Astropy| image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge

.. |Coverage| image:: https://coveralls.io/repos/github/vcalderon2009/sdss_catl_utils/badge.svg?branch=master
   :target: https://coveralls.io/github/vcalderon2009/sdss_catl_utils?branch=master
   :alt: Coveralls Status

.. |Release| image:: https://img.shields.io/github/release/vcalderon2009/sdss_catl_utils.svg
   :target: https://github.com/vcalderon2009/sdss_catl_utils/releases/latest
   :alt: Latest Release

.. |PyPI| image:: https://img.shields.io/pypi/v/sdss-catl-utils.svg
   :target: https://pypi.python.org/pypi/sdss-catl-utils
   :alt: PyPI Release

.. |Travis_Build| image:: https://travis-ci.org/vcalderon2009/sdss_catl_utils.svg?branch=master
   :target: https://travis-ci.org/vcalderon2009/sdss_catl_utils
   :alt: Build Status

.. |Issues| image:: https://img.shields.io/github/issues/vcalderon2009/sdss_catl_utils.svg
   :target: https://github.com/vcalderon2009/sdss_catl_utils/issues
   :alt: Open Issues

.. |RTD| image:: https://readthedocs.org/projects/sdss-catls-utils/badge/?version=latest
   :target: https://sdss-catls-utils.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. |License| image:: https://img.shields.io/badge/License-BSD%203--Clause-blue.svg
   :target: https://opensource.org/licenses/BSD-3-Clause
   :alt: Project License 